==> hom.Rn.inp.db_2.2.5.tar.gz: hom.Rn.inp.db/man/hom.Rn.inpORGVSORGMAP.Rd <==
\name{hom.Rn.inpHOMSA}
\alias{hom.Rn.inpAEDAE}
\alias{hom.Rn.inpANOGA}
\alias{hom.Rn.inpAPIME}
\alias{hom.Rn.inpARATH}
\alias{hom.Rn.inpBOSTA}
\alias{hom.Rn.inpCAEBR}
\alias{hom.Rn.inpCAEEL}
\alias{hom.Rn.inpCAERE}
\alias{hom.Rn.inpCANFA}
\alias{hom.Rn.inpCANGL}
\alias{hom.Rn.inpCIOIN}
\alias{hom.Rn.inpCRYNE}
\alias{hom.Rn.inpDANRE}
\alias{hom.Rn.inpDEBHA}
\alias{hom.Rn.inpDICDI}
\alias{hom.Rn.inpDROME}
\alias{hom.Rn.inpDROPS}
\alias{hom.Rn.inpENTHI}
\alias{hom.Rn.inpESCCO}
\alias{hom.Rn.inpFUGRU}
\alias{hom.Rn.inpGALGA}
\alias{hom.Rn.inpGASAC}
\alias{hom.Rn.inpHOMSA}
\alias{hom.Rn.inpKLULA}
\alias{hom.Rn.inpMACMU}
\alias{hom.Rn.inpMONDO}
\alias{hom.Rn.inpMUSMU}
\alias{hom.Rn.inpORYSA}
\alias{hom.Rn.inpPANTR}
\alias{hom.Rn.inpRATNO}
\alias{hom.Rn.inpSACCE}
\alias{hom.Rn.inpSCHPO}
\alias{hom.Rn.inpTETNI}
\alias{hom.Rn.inpXENTR}
\alias{hom.Rn.inpYARLI}
\title{Map between IDs for genes in one organism to their predicted
  paralogs in another}
\description{ 
  A map of this type is an R object that provides mappings between
  identifiers for genes in the package organism and their predicted
  paralogs in the map that the organism is named after.  So for example,
  if the inparanoid package is the human package, then the
  hom.Rn.inpRATNO map would provide mappings between human and rat.
}
\details{
    Mappings between gene identifiers and their paralogs as predicted by
    the Inparanoid algorithm.  The map filters out paralogs that have an
    Inparanoid score less than 100%.

    Mappings are normally given from the ID of the organism in the
    package to the IDs of the organism listed in the map name.

    Reversal can be made of ANY map by using the function revmap (see
    examples below).

    Names for these maps are done in the "INPARANOID style" which means
    that they are normally the 1st three letters of the genus followed
    by the 1st two letters of the species.  For example: "Mus musculus"
    becomes "MUSMU", "Homo sapiens" becomes "HOMSA", "Monodelphis
    domestica" becomes "MONDO" etc. This means that for most of these
    organisms it will be possible to easily guess the abbreviations
    used.  An exception may occur in the future if a new model organism
    has a very similar genus and species name to an existing one.
}
\references{
\url{http://inparanoid.sbc.su.se/download/current/sqltables}
}
\examples{
        x <- hom.Rn.inpAPIME
        # Get honeybee IDs that are paralogous to the pkg IDs
        mapped_IDs <- mappedkeys(x)
        # Convert to a list
        xx <- as.list(x[mapped_IDs])
        if(length(xx) > 0) {
          # Get the paralogs for the first five genes
          xx[1:5]
          # Get the first one
          xx[[1]]
        }

        #Now for the reverse map (honeybee IDs back to pkg paralog)
        x <- revmap(hom.Rn.inpAPIME)
        mapped_IDs <- mappedkeys(x)
        # Convert to a list
        xx <- as.list(x[mapped_IDs])
        if(length(xx) > 0) {
          # Get the paralogs for the first five IDs
          xx[1:5]
          # Get the first one
          xx[[1]]
        }         

    \dontrun{
        #For the most common organisms, we try to ensure that you can
        #map back to an Entrez Gene ID by providing you with necessary
        #maps in the related organism based annotation packages.  The
        #following example shows how to get from an Entrez Gene ID for
        #Human to Entrez Gene IDs for Mouse even though inparanoid does
        #not map to Entrez Gene IDs for either of these species.

        #You will have to include the appropriate packages for
        #humans:
        library("org.Hs.eg.db")
        #and for mouse:
        library("org.Mm.eg.db")
        #And of course you will need the inparanoid package:
        library("hom.Hs.inp.db")

        #Start with some Human Entrez Gene IDs
        humanEGIds <- c("4488","4487")

        #Inparanoid uses ensembl protein IDs so start with
        #those. Notice that there will be many protein IDs returned for
        #a typical gene since there are many possible translations.
        humanProtIds <- mget(humanEGIds,org.Hs.egENSEMBLPROT)

        #Map the IDs that we can from inparanoid. Notice that by design,
        #inparanoid only represents each gene product with a single
        #translation product. Therefore your list could slim down a lot
        #during this step.  Also, if the thing you are trying to match
        #up at this step has less than 100\% seed status, you will not
        #find it in this step.
        rawMouseProtIds <- mget(unlist(humanProtIds),hom.Hs.inpMUSMU,ifnotfound=NA)
        #This also means that we need to clean up the NAs from our result
        mouseProtIds <- rawMouseProtIds[!is.na(rawMouseProtIds)]

        #Then use the mouse organism based packages to convert these IDs
        #back to an Entrez Gene ID again (this time for mouse). 
        mouseEGIds <- mget(unlist(mouseProtIds),org.Mm.egMGI2EG,ifnotfound=NA)

        #Now go ahead and have a look at the output
        mouseEGIds
    }

}
\keyword{datasets}

==> hom.Rn.inp.db_2.4.1.tar.gz: hom.Rn.inp.db/man/hom.Rn.inpORGVSORGMAP.Rd <==
\name{hom.Rn.inpHOMSA}
\alias{hom.Rn.inpACYPI}
\alias{hom.Rn.inpAEDAE}
\alias{hom.Rn.inpANOGA}
\alias{hom.Rn.inpAPIME}
\alias{hom.Rn.inpARATH}
\alias{hom.Rn.inpASPFU}
\alias{hom.Rn.inpBATDE}
\alias{hom.Rn.inpBOMMO}
\alias{hom.Rn.inpBOSTA}
\alias{hom.Rn.inpBRAFL}
\alias{hom.Rn.inpBRUMA}
\alias{hom.Rn.inpCAEBRE}
\alias{hom.Rn.inpCAEBR}
\alias{hom.Rn.inpCAEEL}
\alias{hom.Rn.inpCAEJA}
\alias{hom.Rn.inpCAERE}
\alias{hom.Rn.inpCANAL}
\alias{hom.Rn.inpCANGL}
\alias{hom.Rn.inpCANFA}
\alias{hom.Rn.inpCAPSP}
\alias{hom.Rn.inpCAVPO}
\alias{hom.Rn.inpCHLRE}
\alias{hom.Rn.inpCIOIN}
\alias{hom.Rn.inpCIOSA}
\alias{hom.Rn.inpCOCIM}
\alias{hom.Rn.inpCOPCI}
\alias{hom.Rn.inpCRYNE}
\alias{hom.Rn.inpCRYHO}
\alias{hom.Rn.inpCRYPA}
\alias{hom.Rn.inpCULPI}
\alias{hom.Rn.inpCYAME}
\alias{hom.Rn.inpDANRE}
\alias{hom.Rn.inpDAPPU}
\alias{hom.Rn.inpDEBHA}
\alias{hom.Rn.inpDICDI}
\alias{hom.Rn.inpDROAN}
\alias{hom.Rn.inpDROGR}
\alias{hom.Rn.inpDROME}
\alias{hom.Rn.inpDROMO}
\alias{hom.Rn.inpDROPS}
\alias{hom.Rn.inpDROVI}
\alias{hom.Rn.inpDROWI}
\alias{hom.Rn.inpENTHI}
\alias{hom.Rn.inpEQUCA}
\alias{hom.Rn.inpESCCO}
\alias{hom.Rn.inpFUSGR}
\alias{hom.Rn.inpGALGA}
\alias{hom.Rn.inpGASAC}
\alias{hom.Rn.inpGIALA}
\alias{hom.Rn.inpHELRO}
\alias{hom.Rn.inpHOMSA}
\alias{hom.Rn.inpIXOSC}
\alias{hom.Rn.inpKLULA}
\alias{hom.Rn.inpLEIMA}
\alias{hom.Rn.inpLOTGI}
\alias{hom.Rn.inpMACMU}
\alias{hom.Rn.inpMAGGR}
\alias{hom.Rn.inpMONDO}
\alias{hom.Rn.inpMONBR}
\alias{hom.Rn.inpMUSMU}
\alias{hom.Rn.inpNASVI}
\alias{hom.Rn.inpNEMVE}
\alias{hom.Rn.inpNEUCR}
\alias{hom.Rn.inpORNAN}
\alias{hom.Rn.inpORYSA}
\alias{hom.Rn.inpORYLA}
\alias{hom.Rn.inpOSTTA}
\alias{hom.Rn.inpPANTR}
\alias{hom.Rn.inpPEDPA}
\alias{hom.Rn.inpPHYPA}
\alias{hom.Rn.inpPHYRA}
\alias{hom.Rn.inpPHYSO}
\alias{hom.Rn.inpPLAFA}
\alias{hom.Rn.inpPLAVI}
\alias{hom.Rn.inpPONPY}
\alias{hom.Rn.inpPOPTR}
\alias{hom.Rn.inpPRIPA}
\alias{hom.Rn.inpPUCGR}
\alias{hom.Rn.inpRATNO}
\alias{hom.Rn.inpRHIOR}
\alias{hom.Rn.inpSACCE}
\alias{hom.Rn.inpSCHMA}
\alias{hom.Rn.inpSCHPO}
\alias{hom.Rn.inpSCLSC}
\alias{hom.Rn.inpSORBI}
\alias{hom.Rn.inpSTANO}
\alias{hom.Rn.inpSTRPU}
\alias{hom.Rn.inpTAKRU}
\alias{hom.Rn.inpTETTH}
\alias{hom.Rn.inpTETNI}
\alias{hom.Rn.inpTHAPS}
\alias{hom.Rn.inpTHEAN}
\alias{hom.Rn.inpTHEPA}
\alias{hom.Rn.inpTRICA}
\alias{hom.Rn.inpTRIVA}
\alias{hom.Rn.inpTRIAD}
\alias{hom.Rn.inpTRYCR}
\alias{hom.Rn.inpUSTMA}
\alias{hom.Rn.inpXENTR}
\alias{hom.Rn.inpYARLI}
\title{Map between IDs for genes in one organism to their predicted
  paralogs in another}
\description{ 
  A map of this type is an R object that provides mappings between
  identifiers for genes in the package organism and their predicted
  paralogs in the map that the organism is named after.  So for example,
  if the inparanoid package is the human package, then the
  hom.Rn.inpRATNO map would provide mappings between human and rat.
}
\details{
    Mappings between gene identifiers and their paralogs as predicted by
    the Inparanoid algorithm.  The map filters out paralogs that have an
    Inparanoid score less than 100%.

    Mappings are normally given from the ID of the organism in the
    package to the IDs of the organism listed in the map name.

    Reversal can be made of ANY map by using the function revmap (see
    examples below).

    Names for these maps are done in the "INPARANOID style" which means
    that they are normally the 1st three letters of the genus followed
    by the 1st two letters of the species.  For example: "Mus musculus"
    becomes "MUSMU", "Homo sapiens" becomes "HOMSA", "Monodelphis
    domestica" becomes "MONDO" etc. This means that for most of these
    organisms it will be possible to easily guess the abbreviations
    used.  An exception may occur in the future if a new model organism
    has a very similar genus and species name to an existing one.
}
\references{
\url{http://inparanoid.sbc.su.se/download/current/sqltables}
}
\examples{
        x <- hom.Rn.inpAPIME
        # Get honeybee IDs that are paralogous to the pkg IDs
        mapped_IDs <- mappedkeys(x)
        # Convert to a list
        xx <- as.list(x[mapped_IDs])
        if(length(xx) > 0) {
          # Get the paralogs for the first five genes
          xx[1:5]
          # Get the first one
          xx[[1]]
        }

        #Now for the reverse map (honeybee IDs back to pkg paralog)
        x <- revmap(hom.Rn.inpAPIME)
        mapped_IDs <- mappedkeys(x)
        # Convert to a list
        xx <- as.list(x[mapped_IDs])
        if(length(xx) > 0) {
          # Get the paralogs for the first five IDs
          xx[1:5]
          # Get the first one
          xx[[1]]
        }         

    \dontrun{
        #For the most common organisms, we try to ensure that you can
        #map back to an Entrez Gene ID by providing you with necessary
        #maps in the related organism based annotation packages.  The
        #following example shows how to get from an Entrez Gene ID for
        #Human to Entrez Gene IDs for Mouse even though inparanoid does
        #not map to Entrez Gene IDs for either of these species.

        #You will have to include the appropriate packages for
        #humans:
        library("org.Hs.eg.db")
        #and for mouse:
        library("org.Mm.eg.db")
        #And of course you will need the inparanoid package:
        library("hom.Hs.inp.db")

        #Start with some Human Entrez Gene IDs
        humanEGIds <- c("4488","4487")

        #Inparanoid uses ensembl protein IDs so start with
        #those. Notice that there will be many protein IDs returned for
        #a typical gene since there are many possible translations.
        humanProtIds <- mget(humanEGIds,org.Hs.egENSEMBLPROT)

        #Map the IDs that we can from inparanoid. Notice that by design,
        #inparanoid only represents each gene product with a single
        #translation product. Therefore your list could slim down a lot
        #during this step.  Also, if the thing you are trying to match
        #up at this step has less than 100\% seed status, you will not
        #find it in this step.
        rawMouseProtIds <- mget(unlist(humanProtIds),hom.Hs.inpMUSMU,ifnotfound=NA)
        #This also means that we need to clean up the NAs from our result
        mouseProtIds <- rawMouseProtIds[!is.na(rawMouseProtIds)]

        #Then use the mouse organism based packages to convert these IDs
        #back to an Entrez Gene ID again (this time for mouse). 
        mouseEGIds <- mget(unlist(mouseProtIds),org.Mm.egMGI2EG,ifnotfound=NA)

        #Now go ahead and have a look at the output
        mouseEGIds
    }

}
\keyword{datasets}
